@@ -129,7 +129,7 @@ gssdp_client_constructed (GObject *object)
 
         /* Set up sockets (Will set errno if it failed) */
         client->priv->request_socket =
-                gssdp_socket_source_new (GSSPP_SOCKET_SOURCE_TYPE_REQUEST,
+                gssdp_socket_source_new (GSSDP_SOCKET_SOURCE_TYPE_REQUEST,
                                          gssdp_client_get_host_ip (client));
         if (client->priv->request_socket != NULL) {
                 g_source_set_callback
@@ -268,6 +268,8 @@ gssdp_client_dispose (GObject *object)
                 g_main_context_unref (client->priv->main_context);
                 client->priv->main_context = NULL;
         }
+
+        G_OBJECT_CLASS (gssdp_client_parent_class)->dispose (object);
 }
 
 static void
@@ -280,6 +282,8 @@ gssdp_client_finalize (GObject *object)
         g_free (client->priv->server_id);
         g_free (client->priv->interface);
         g_free (client->priv->host_ip);
+
+        G_OBJECT_CLASS (gssdp_client_parent_class)->finalize (object);
 }
 
 static void
@@ -424,7 +428,7 @@ gssdp_client_class_init (GSSDPClientClass *klass)
                               gssdp_marshal_VOID__STRING_UINT_INT_POINTER,
                               G_TYPE_NONE,
                               4,
-                              G_TYPE_STRING,
+                              G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
                               G_TYPE_UINT,
                               G_TYPE_INT,
                               G_TYPE_POINTER);
@@ -709,7 +713,7 @@ static gboolean
 socket_source_cb (GSSDPSocketSource *socket, GSSDPClient *client)
 {
         int fd, type, len;
-        size_t bytes;
+        ssize_t bytes;
         char buf[BUF_SIZE], *end;
         struct sockaddr_in addr;
         socklen_t addr_size;
@@ -730,6 +734,13 @@ socket_source_cb (GSSDPSocketSource *socket, GSSDPClient *client)
                           MSG_TRUNC,
                           (struct sockaddr *) &addr,
                           &addr_size);
+        if (bytes == -1) {
+                g_warning ("Failed to read from socket: %d (%s)",
+                           errno,
+                           strerror (errno));
+
+                return TRUE;
+        }
 
         /* We need the following lines to make sure the right client received
          * the packet. We won't need to do this if there was any way to tell
