@@ -27,12 +27,13 @@ G_BEGIN_DECLS
 typedef struct _GSSDPSocketSource GSSDPSocketSource;
 
 typedef enum {
-        GSSPP_SOCKET_SOURCE_TYPE_REQUEST,
+        GSSDP_SOCKET_SOURCE_TYPE_REQUEST,
         GSSDP_SOCKET_SOURCE_TYPE_MULTICAST
 } GSSDPSocketSourceType;
 
 G_GNUC_INTERNAL GSSDPSocketSource *
-gssdp_socket_source_new    (GSSDPSocketSourceType type);
+gssdp_socket_source_new    (GSSDPSocketSourceType type,
+                            const char           *host_ip);
 
 G_GNUC_INTERNAL int
 gssdp_socket_source_get_fd (GSSDPSocketSource    *socket_source);
